==> infima_client-0.59.0-py3-none-any.whl: infima_client/api/pool_service/pool_service_get_quartiles.py <==
from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import Client
from ...models.pool_quartiles import PoolQuartiles
from ...models.pool_quartiles_error import PoolQuartilesError
from ...models.pool_quartiles_not_found import PoolQuartilesNotFound
from ...models.pool_quartiles_unauthorized import PoolQuartilesUnauthorized
from ...types import UNSET, Response


def _get_kwargs(
    *,
    client: Client,
    cusips: List[str],
) -> Dict[str, Any]:
    url = "{}/api/v1/pools/quartiles".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_cusips = cusips

    params: Dict[str, Any] = {
        "CUSIPS": json_cusips,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    if response.status_code == 200:
        response_200 = PoolQuartiles.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = PoolQuartilesUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = PoolQuartilesNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = PoolQuartilesError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    cusips: List[str],
) -> Response[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cusips=cusips,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    cusips: List[str],
) -> Optional[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    """


    Args:
        cusips: Pool CUSIPS to fetch.

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        cusips=cusips,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    cusips: List[str],
) -> Response[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cusips=cusips,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    cusips: List[str],
) -> Optional[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            cusips=cusips,
        )
    ).parsed

==> infima_client-0.186.0-py3-none-any.whl: infima_client/api/pool_service/pool_service_get_quartiles.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.get_quartiles_request import GetQuartilesRequest
from ...models.pool_quartiles import PoolQuartiles
from ...models.pool_quartiles_error import PoolQuartilesError
from ...models.pool_quartiles_not_found import PoolQuartilesNotFound
from ...models.pool_quartiles_unauthorized import PoolQuartilesUnauthorized
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: GetQuartilesRequest,
) -> Dict[str, Any]:
    url = "{}/api/v1/pools/quartiles".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    if response.status_code == 200:
        response_200 = PoolQuartiles.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = PoolQuartilesUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = PoolQuartilesNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = PoolQuartilesError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: GetQuartilesRequest,
) -> Response[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: GetQuartilesRequest,
) -> Optional[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    """


    Args:

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: GetQuartilesRequest,
) -> Response[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: GetQuartilesRequest,
) -> Optional[
    Union[
        PoolQuartiles,
        PoolQuartilesUnauthorized,
        PoolQuartilesNotFound,
        PoolQuartilesError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
